@@ -49,6 +49,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import cdk8s
@@ -77,9 +79,11 @@ class CDK8sProvider(
         config_context_cluster: typing.Optional[builtins.str] = None,
         config_path: typing.Optional[builtins.str] = None,
         config_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
-        exec: typing.Optional[cdktf_cdktf_provider_kubernetes.KubernetesProviderExec] = None,
-        experiments: typing.Optional[cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments] = None,
+        exec: typing.Optional[typing.Union[cdktf_cdktf_provider_kubernetes.KubernetesProviderExec, typing.Dict[str, typing.Any]]] = None,
+        experiments: typing.Optional[typing.Union[cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments, typing.Dict[str, typing.Any]]] = None,
         host: typing.Optional[builtins.str] = None,
+        ignore_annotations: typing.Optional[typing.Sequence[builtins.str]] = None,
+        ignore_labels: typing.Optional[typing.Sequence[builtins.str]] = None,
         insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
         password: typing.Optional[builtins.str] = None,
         proxy_url: typing.Optional[builtins.str] = None,
@@ -102,12 +106,18 @@ class CDK8sProvider(
         :param exec: exec block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#exec KubernetesProvider#exec}
         :param experiments: experiments block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#experiments KubernetesProvider#experiments}
         :param host: The hostname (in form of URI) of Kubernetes master. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#host KubernetesProvider#host}
+        :param ignore_annotations: List of Kubernetes metadata annotations to ignore across all resources handled by this provider for situations where external systems are managing certain resource annotations. Each item is a regular expression. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#ignore_annotations KubernetesProvider#ignore_annotations}
+        :param ignore_labels: List of Kubernetes metadata labels to ignore across all resources handled by this provider for situations where external systems are managing certain resource labels. Each item is a regular expression. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#ignore_labels KubernetesProvider#ignore_labels}
         :param insecure: Whether server should be accessed without verifying the TLS certificate. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#insecure KubernetesProvider#insecure}
         :param password: The password to use for HTTP basic authentication when accessing the Kubernetes master endpoint. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#password KubernetesProvider#password}
         :param proxy_url: URL to the proxy to be used for all API requests. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#proxy_url KubernetesProvider#proxy_url}
         :param token: Token to authenticate an service account. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#token KubernetesProvider#token}
         :param username: The username to use for HTTP basic authentication when accessing the Kubernetes master endpoint. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#username KubernetesProvider#username}
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CDK8sProvider.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = CDK8sProviderConfig(
             cdk8s_app=cdk8s_app,
             alias=alias,
@@ -122,6 +132,8 @@ class CDK8sProvider(
             exec=exec,
             experiments=experiments,
             host=host,
+            ignore_annotations=ignore_annotations,
+            ignore_labels=ignore_labels,
             insecure=insecure,
             password=password,
             proxy_url=proxy_url,
@@ -148,6 +160,8 @@ class CDK8sProvider(
         "exec": "exec",
         "experiments": "experiments",
         "host": "host",
+        "ignore_annotations": "ignoreAnnotations",
+        "ignore_labels": "ignoreLabels",
         "insecure": "insecure",
         "password": "password",
         "proxy_url": "proxyUrl",
@@ -169,9 +183,11 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
         config_context_cluster: typing.Optional[builtins.str] = None,
         config_path: typing.Optional[builtins.str] = None,
         config_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
-        exec: typing.Optional[cdktf_cdktf_provider_kubernetes.KubernetesProviderExec] = None,
-        experiments: typing.Optional[cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments] = None,
+        exec: typing.Optional[typing.Union[cdktf_cdktf_provider_kubernetes.KubernetesProviderExec, typing.Dict[str, typing.Any]]] = None,
+        experiments: typing.Optional[typing.Union[cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments, typing.Dict[str, typing.Any]]] = None,
         host: typing.Optional[builtins.str] = None,
+        ignore_annotations: typing.Optional[typing.Sequence[builtins.str]] = None,
+        ignore_labels: typing.Optional[typing.Sequence[builtins.str]] = None,
         insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
         password: typing.Optional[builtins.str] = None,
         proxy_url: typing.Optional[builtins.str] = None,
@@ -192,6 +208,8 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
         :param exec: exec block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#exec KubernetesProvider#exec}
         :param experiments: experiments block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#experiments KubernetesProvider#experiments}
         :param host: The hostname (in form of URI) of Kubernetes master. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#host KubernetesProvider#host}
+        :param ignore_annotations: List of Kubernetes metadata annotations to ignore across all resources handled by this provider for situations where external systems are managing certain resource annotations. Each item is a regular expression. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#ignore_annotations KubernetesProvider#ignore_annotations}
+        :param ignore_labels: List of Kubernetes metadata labels to ignore across all resources handled by this provider for situations where external systems are managing certain resource labels. Each item is a regular expression. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#ignore_labels KubernetesProvider#ignore_labels}
         :param insecure: Whether server should be accessed without verifying the TLS certificate. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#insecure KubernetesProvider#insecure}
         :param password: The password to use for HTTP basic authentication when accessing the Kubernetes master endpoint. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#password KubernetesProvider#password}
         :param proxy_url: URL to the proxy to be used for all API requests. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#proxy_url KubernetesProvider#proxy_url}
@@ -203,6 +221,28 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
             exec = cdktf_cdktf_provider_kubernetes.KubernetesProviderExec(**exec)
         if isinstance(experiments, dict):
             experiments = cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments(**experiments)
+        if __debug__:
+            type_hints = typing.get_type_hints(CDK8sProviderConfig.__init__)
+            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
+            check_type(argname="argument client_certificate", value=client_certificate, expected_type=type_hints["client_certificate"])
+            check_type(argname="argument client_key", value=client_key, expected_type=type_hints["client_key"])
+            check_type(argname="argument cluster_ca_certificate", value=cluster_ca_certificate, expected_type=type_hints["cluster_ca_certificate"])
+            check_type(argname="argument config_context", value=config_context, expected_type=type_hints["config_context"])
+            check_type(argname="argument config_context_auth_info", value=config_context_auth_info, expected_type=type_hints["config_context_auth_info"])
+            check_type(argname="argument config_context_cluster", value=config_context_cluster, expected_type=type_hints["config_context_cluster"])
+            check_type(argname="argument config_path", value=config_path, expected_type=type_hints["config_path"])
+            check_type(argname="argument config_paths", value=config_paths, expected_type=type_hints["config_paths"])
+            check_type(argname="argument exec", value=exec, expected_type=type_hints["exec"])
+            check_type(argname="argument experiments", value=experiments, expected_type=type_hints["experiments"])
+            check_type(argname="argument host", value=host, expected_type=type_hints["host"])
+            check_type(argname="argument ignore_annotations", value=ignore_annotations, expected_type=type_hints["ignore_annotations"])
+            check_type(argname="argument ignore_labels", value=ignore_labels, expected_type=type_hints["ignore_labels"])
+            check_type(argname="argument insecure", value=insecure, expected_type=type_hints["insecure"])
+            check_type(argname="argument password", value=password, expected_type=type_hints["password"])
+            check_type(argname="argument proxy_url", value=proxy_url, expected_type=type_hints["proxy_url"])
+            check_type(argname="argument token", value=token, expected_type=type_hints["token"])
+            check_type(argname="argument username", value=username, expected_type=type_hints["username"])
+            check_type(argname="argument cdk8s_app", value=cdk8s_app, expected_type=type_hints["cdk8s_app"])
         self._values: typing.Dict[str, typing.Any] = {
             "cdk8s_app": cdk8s_app,
         }
@@ -230,6 +270,10 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
             self._values["experiments"] = experiments
         if host is not None:
             self._values["host"] = host
+        if ignore_annotations is not None:
+            self._values["ignore_annotations"] = ignore_annotations
+        if ignore_labels is not None:
+            self._values["ignore_labels"] = ignore_labels
         if insecure is not None:
             self._values["insecure"] = insecure
         if password is not None:
@@ -344,6 +388,28 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
         result = self._values.get("host")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def ignore_annotations(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''List of Kubernetes metadata annotations to ignore across all resources handled by this provider for situations where external systems are managing certain resource annotations.
+
+        Each item is a regular expression.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#ignore_annotations KubernetesProvider#ignore_annotations}
+        '''
+        result = self._values.get("ignore_annotations")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
+    @builtins.property
+    def ignore_labels(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''List of Kubernetes metadata labels to ignore across all resources handled by this provider for situations where external systems are managing certain resource labels.
+
+        Each item is a regular expression.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#ignore_labels KubernetesProvider#ignore_labels}
+        '''
+        result = self._values.get("ignore_labels")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     @builtins.property
     def insecure(
         self,
